ServEnvironmentRequest

Struct ServEnvironmentRequest 

pub struct ServEnvironmentRequest<'g, 'a> { /* private fields */ }
An environment variable request

Implementations

Source

impl<'g, 'a> ServEnvironmentRequest<'g, 'a>

pub fn succeed(self) -> Result<()>

Indicate that the request succeeded.

Note that if the peer didn’t request a reply, this call will not do anything.

pub fn fail(self) -> Result<()>

Indicate that the request failed.

Note that if the peer didn’t request a reply, this call will not do anything. Does not need to be called explicitly, also occurs on drop without accept()

pub fn channel(&self) -> ChanNum

Return the associated channel number.

This will correspond to a ChanHandle::num() from a previous ServOpenSession event.

pub fn name(&self) -> Result<&str>

Retrieve the name of the environment variable (from NAME=VALUE pair).

pub fn value(&self) -> Result<&str>

Retrieve the value of the environment variable (from NAME=VALUE pair).