Module namelist

Module namelist 

SSH comma separated algorithm lists.

Used when implementing protocol encoding/decoding, not required for general SSH session use.

Structs

LocalNames
A list of names, can only be encoded. Used for local name lists, comes from local fixed lists
StringNames
A comma separated string, can be decoded or encoded. Used for remote name lists.

Enums

NameList
The general form that can store either representation

Constants

MAX_LOCAL_NAMES
Max count of LocalNames entries