pub enum CliEvent<'g, 'a> {
Hostkey(CheckHostkey<'g, 'a>),
Banner(Banner<'g>),
Username(RequestUsername<'g, 'a>),
Password(RequestPassword<'g, 'a>),
Pubkey(RequestPubkey<'g, 'a>),
AgentSign(RequestSign<'g, 'a>),
Authenticated,
SessionOpened(CliSessionOpener<'g, 'a>),
SessionExit(CliSessionExit<'g>),
Defunct,
PollAgain,
}Expand description
Client events.
These events are returned by the progress() function
which is polled during the course of the connection.
The application can call response functions on the associated
enum item, for example providing a username or password
for authentication.
Variants
Hostkey(CheckHostkey<'g, 'a>)
Banner(Banner<'g>)
Username(RequestUsername<'g, 'a>)
Password(RequestPassword<'g, 'a>)
Pubkey(RequestPubkey<'g, 'a>)
AgentSign(RequestSign<'g, 'a>)
Authenticated
SessionOpened(CliSessionOpener<'g, 'a>)
SessionExit(CliSessionExit<'g>)
Remote process exited
Defunct
The SSH connection is no longer running
PollAgain
No event was returned.
The caller should poll progress() again.