pub struct ServEnvironmentRequest<'g, 'a> { /* private fields */ }Expand description
An environment variable request
Implementations
Sourceimpl<'g, 'a> ServEnvironmentRequest<'g, 'a>
impl<'g, 'a> ServEnvironmentRequest<'g, 'a>
Sourcepub fn succeed(self) -> Result<()>
pub fn succeed(self) -> Result<()>
Indicate that the request succeeded.
Note that if the peer didn’t request a reply, this call will not do anything.
Sourcepub fn fail(self) -> Result<()>
pub fn fail(self) -> Result<()>
Indicate that the request failed.
Note that if the peer didn’t request a reply, this call
will not do anything.
Does not need to be called explicitly, also occurs on drop without accept()
Sourcepub fn channel(&self) -> ChanNum
pub fn channel(&self) -> ChanNum
Return the associated channel number.
This will correspond to a ChanHandle::num()
from a previous ServOpenSession event.